%define debug_package %{nil}

Name:           traefik
Version:        3.3.2
Release:        1%{?dist}
Summary:        Traefik, a modern reverse proxy
Group:          System Environment/Daemons
License:        MIT
URL:            https://traefik.io/
Packager:       Teddysun <i@teddysun.com>
Source0:        https://github.com/traefik/traefik/archive/refs/tags/v%{version}.tar.gz#/traefik-%{version}.tar.gz
Source1:        traefik.service
Source2:        traefik.sysconfig
Source3:        traefik.sysusers

BuildRequires:  systemd-units
Requires(pre):  shadow-utils
BuildRequires:  git-core
BuildRequires:  systemd-rpm-macros
%{?systemd_requires}
Requires:       libcap

%description
Traefik is a modern HTTP reverse proxy and load balancer made to deploy
microservices with ease. It supports several backends (Docker, Swarm,
Mesos/Marathon, Consul, Etcd, Zookeeper, BoltDB, Rest API, file...) to manage
its configuration automatically and dynamically.

%prep
%setup -q -n %{name}-%{version}

%build
# https://pagure.io/go-rpm-macros/c/1cc7f5d9026175bb6cb1b8c889355d0c4fc0e40a
%undefine _auto_set_build_flags
LDFLAGS="-s -w -buildid="
GIT_REPO_URL='github.com/traefik/traefik/v3/pkg/version'
DATE=$(date -u '+%Y-%m-%d')
env CGO_ENABLED=0 go build -v -trimpath -ldflags "-X ${GIT_REPO_URL}.Version=v%{version} -X ${GIT_REPO_URL}.BuildDate=${DATE} ${LDFLAGS}" -o traefik ./cmd/traefik

%install
%{__install} -D -p -m 755 traefik %{buildroot}%{_bindir}/%{name}
%{__install} -D -p -m 644 traefik.sample.toml %{buildroot}%{_sysconfdir}/%{name}/%{name}.toml
%{__install} -D -p -m 644 %{S:1} %{buildroot}%{_unitdir}/%{name}.service
%{__install} -D -p -m 644 %{S:2} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
# sysusers
%{__install} -D -p -m 644 %{S:3} %{buildroot}%{_sysusersdir}/%{name}.conf
# data directory
%{__install} -d -m 0750 %{buildroot}%{_datadir}/%{name}
%{__install} -d -m 0750 %{buildroot}%{_sharedstatedir}/%{name}

%pre
%sysusers_create_package %{name} %{S:3}

%post
%systemd_post %{name}.service

if [ -x /usr/sbin/getsebool ]; then
    # connect to ACME endpoint to request certificates
    setsebool -P httpd_can_network_connect on
fi
if [ -x /usr/sbin/semanage -a -x /usr/sbin/restorecon ]; then
    # file contexts
    semanage fcontext --add --type httpd_exec_t        '%{_bindir}/traefik'               >/dev/null 2>&1 || :
    semanage fcontext --add --type httpd_sys_content_t '%{_datadir}/traefik(/.*)?'        >/dev/null 2>&1 || :
    semanage fcontext --add --type httpd_config_t      '%{_sysconfdir}/traefik(/.*)?'     >/dev/null 2>&1 || :
    semanage fcontext --add --type httpd_var_lib_t     '%{_sharedstatedir}/traefik(/.*)?' >/dev/null 2>&1 || :
    restorecon -r %{_bindir}/traefik %{_datadir}/traefik %{_sysconfdir}/traefik %{_sharedstatedir}/traefik || :
fi
if [ -x /usr/sbin/semanage ]; then
    # QUIC
    semanage port --add --type http_port_t --proto udp 80   >/dev/null 2>&1 || :
    semanage port --add --type http_port_t --proto udp 443  >/dev/null 2>&1 || :
    semanage port --add --type http_port_t --proto tcp 8080 >/dev/null 2>&1 || :
fi
setcap cap_net_bind_service+ep %{_bindir}/%{name}

%preun
%systemd_preun %{name}.service

%postun
%systemd_postun_with_restart %{name}.service

if [ $1 -eq 0 ]; then
    if [ -x /usr/sbin/getsebool ]; then
        # connect to ACME endpoint to request certificates
        setsebool -P httpd_can_network_connect off
    fi
    if [ -x /usr/sbin/semanage ]; then
        # file contexts
        semanage fcontext --delete --type httpd_exec_t        '%{_bindir}/traefik'               >/dev/null 2>&1 || :
        semanage fcontext --delete --type httpd_sys_content_t '%{_datadir}/traefik(/.*)?'        >/dev/null 2>&1 || :
        semanage fcontext --delete --type httpd_config_t      '%{_sysconfdir}/traefik(/.*)?'     >/dev/null 2>&1 || :
        semanage fcontext --delete --type httpd_var_lib_t     '%{_sharedstatedir}/traefik(/.*)?' >/dev/null 2>&1 || :
        # QUIC
        semanage port     --delete --type http_port_t --proto udp 80   >/dev/null 2>&1 || :
        semanage port     --delete --type http_port_t --proto udp 443  >/dev/null 2>&1 || :
        semanage port     --delete --type http_port_t --proto tcp 8080 >/dev/null 2>&1 || :
    fi
fi

%files
%license LICENSE.md
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_unitdir}/%{name}.service
%{_sysconfdir}/sysconfig/%{name}
%{_sysusersdir}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.toml
%attr(0750,traefik,traefik) %dir %{_sharedstatedir}/%{name}

%changelog
* Thu Jan 16 2025 Teddysun <i@teddysun.com> - 3.3.2-1
- Update version to 3.3.2

* Wed Jan 08 2025 Teddysun <i@teddysun.com> - 3.2.5-1
- Update version to 3.2.5

* Mon Jan 06 2025 Teddysun <i@teddysun.com> - 3.2.4-1
- Update version to 3.2.4

* Mon Dec 30 2024 Teddysun <i@teddysun.com> - 3.2.3-1
- Update version to 3.2.3
